# README
## Refer to streamlit_example.py in example folder
- install streamlit_sentence_selector lib
```shell
pip install streamlit_sentence_selector
```

- import package in a python file
```python
from streamlit_sentence_selector import sentence_selector
```
- calling this function
```python
res=sentence_selector(sentences=strings,key = '')
# strings is a list of string 
# res is a list that you selected in web page
```

## The effect is shown below
![img.png](img.png)